@@ -32,6 +32,9 @@ class ABCWebhookService(metaclass=ABCMeta):
     self._app = app
     self._handlers: Dict[str, EventHandler] = dict()
 
+    @app.get("/healthz")
+    async def healthz():
+      return "OK"
 
     @app.post("/event")
     async def handleEvent(request: Request) -> Any:
@@ -46,6 +49,9 @@ class ABCWebhookService(metaclass=ABCMeta):
       action = json["action"]
 
       handler_type = f"{event}-{action}".replace("_", "-")
+      if handler_type not in self._handlers:
+        return JSONResponse(status_code=status.HTTP_404_NOT_FOUND, content={"message": "Not Found"})
+      
       handler = self._handlers[handler_type]
 
       if handler is None:
@@ -56,7 +62,7 @@ class ABCWebhookService(metaclass=ABCMeta):
         if header_name in request.headers:
           event_headers[header_name] = request.headers[header_name]
       
-      return handler.method(headers=event_headers, request=handler.bodyType(**json))
+      return handler.method(self._target, headers=event_headers, request=handler.bodyType(**json))
 
   def webhook(self, cls):
     if cls is None:
@@ -65,8 +71,10 @@ class ABCWebhookService(metaclass=ABCMeta):
     resolved = None
     if inspect.isclass(cls):
       resolved = cls
+      self._target = cls()
     elif hasattr(cls, "__class__"):
       resolved = cls.__class__
+      self._target = cls
 
     resolved._is_github_webhook_cls = True
     self._target = cls
